@@ -26,6 +26,26 @@ def wms_resp():
         layers="NLCD_2011_Tree_Canopy_L48",
         outformat="image/geotiff",
         crs=DEF_CRS,
+        validation=False,
+        ssl=False,
+    )
+    return wms.getmap_bybox(
+        GEO_NAT.bounds,
+        1e3,
+        box_crs=DEF_CRS,
+    )
+
+
+@pytest.fixture()
+def cover_resp():
+    """Return a WMS response."""
+    wms = WMS(
+        ServiceURL().wms.mrlc,
+        layers="NLCD_2019_Land_Cover_Science_Product_L48",
+        outformat="image/geotiff",
+        crs=DEF_CRS,
+        validation=False,
+        ssl=False,
     )
     return wms.getmap_bybox(
         GEO_NAT.bounds,
