@@ -1,6 +1,11 @@
 """Top-level package for PyGeoUtils."""
 from importlib.metadata import PackageNotFoundError, version
 
+if int(version("shapely").split(".")[0]) > 1:
+    import os
+
+    os.environ["USE_PYGEOS"] = "0"
+
 from ._utils import transform2tuple
 from .exceptions import (
     EmptyResponseError,
