@@ -1,11 +1,12 @@
 """Some utilities for manipulating GeoSpatial data."""
 from __future__ import annotations
 
+import itertools
 import tempfile
 import uuid
 from dataclasses import dataclass
 from pathlib import Path
-from typing import Any, Sequence, Tuple, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Sequence, Tuple, TypeVar, Union
 
 import cytoolz as tlz
 import dask
@@ -37,11 +38,12 @@ from .exceptions import (
 )
 
 BOX_ORD = "(west, south, east, north)"
-GTYPE = Union[Polygon, MultiPolygon, Tuple[float, float, float, float]]
-GDF = TypeVar("GDF", gpd.GeoDataFrame, gpd.GeoSeries)
-XD = TypeVar("XD", xr.Dataset, xr.DataArray)
-CRSTYPE = Union[int, str, pyproj.CRS]
 NUMBER = Union[int, float, np.number]
+if TYPE_CHECKING:
+    GTYPE = Union[Polygon, MultiPolygon, Tuple[float, float, float, float]]
+    GDF = TypeVar("GDF", gpd.GeoDataFrame, gpd.GeoSeries)
+    XD = TypeVar("XD", xr.Dataset, xr.DataArray)
+    CRSTYPE = Union[int, str, pyproj.CRS]
 
 __all__ = [
     "snap2nearest",
@@ -122,7 +124,7 @@ def json2geodf(
     if len(content) > 1:
         geodf = gpd.GeoDataFrame(pd.concat(gpd.GeoDataFrame.from_features(c) for c in content))
 
-    if "geometry" in geodf and len(geodf) > 0:
+    if "geometry" in geodf and not geodf.geometry.is_empty.all():
         geodf = geodf.set_crs(in_crs)
         if in_crs != crs:
             geodf = geodf.to_crs(crs)
@@ -165,7 +167,7 @@ def geo2polygon(
     return geom
 
 
-def _write_crs(ds: XD)->XD:
+def _write_crs(ds: XD) -> XD:
     """Write geo reference info into a dataset or dataarray."""
     ds = ds.rio.write_transform()
     if ds.rio.grid_mapping and ds.rio.grid_mapping != "spatial_ref":
@@ -178,7 +180,6 @@ def _write_crs(ds: XD)->XD:
     return ds
 
 
-
 def xarray_geomask(
     ds: XD,
     geometry: GTYPE,
@@ -224,7 +225,7 @@ def xarray_geomask(
 
     geom = geo2polygon(geometry, crs, ds.rio.crs)
     ds = _write_crs(ds)
-    ds = ds.rio.clip_box(*geom.bounds)
+    ds = ds.rio.clip_box(*geom.bounds, auto_expand=True)
     if isinstance(geometry, (Polygon, MultiPolygon)):
         ds = ds.rio.clip([geom], all_touched=all_touched, drop=drop, from_disk=from_disk)
 
@@ -366,7 +367,7 @@ def gtiff2xarray(
 
     with dask.config.set(**{"array.slicing.split_large_chunks": True}):
         ds = xr.open_mfdataset(
-            (to_dataset(lyr, resp) for lyr, resp in r_dict.items()),
+            itertools.starmap(to_dataset, r_dict.items()),
             chunks="auto",
             parallel=True,
             engine="rasterio",
