@@ -99,7 +99,7 @@ def test_json2geodf():
     rjosn = service.get_features(oids, return_m=True)
     flw = geoutils.json2geodf(rjosn * 2, ALT_CRS, DEF_CRS)
 
-    assert_close(flw["LENGTHKM"].sum(), 8.917 * 2)
+    assert_close(flw["lengthkm"].sum(), 8.917 * 2)
 
 
 def test_gtiff2array(wms_resp, cover_resp):
@@ -361,4 +361,4 @@ def test_nested():
 def test_show_versions():
     f = io.StringIO()
     geoutils.show_versions(file=f)
-    assert "INSTALLED VERSIONS" in f.getvalue()
+    assert "SYS INFO" in f.getvalue()
